@@ -126,7 +126,7 @@ def create_department(data: dict) -> dict:
     checked = DepartmentForms(data)
     # 判断数据合法性
     if not checked.is_valid():
-        return Resp(code=ServerErrorCode, msg="error", data=checked.errors)
+        return Resp(code=ServerErrorCode, msg=checked.errors)
     # 构造path
     parent_id = data.pop("parent_id")
     parent = Department.objects.get(pk=parent_id)
@@ -150,7 +150,7 @@ def create_department(data: dict) -> dict:
 
     # 如果当前部门下有这个部门
     if same_level_department:
-        return Resp(code=ServerErrorCode, msg="error", data=f"[{data['name']}]在当前部门下已存在, 请使用其他名称")
+        return Resp(code=ServerErrorCode, msg=f"[{data['name']}]在当前部门下已存在, 请使用其他名称")
 
     department_instance = Department.objects.create(**data)
     return Resp(data={'id': department_instance.pk})
@@ -166,7 +166,13 @@ def get_department_object(organization_id: int, pk: int):
     try:
         instance = Department.objects.get(pk=pk, organization_id=organization_id, is_deleted=False)
         return Resp(
-            data={"id": instance.id, "name": instance.name, "path": instance.path, "charger_id": instance.charger_id}
+            data={
+                "id": instance.id,
+                "name": instance.name,
+                "path": instance.path,
+                "charger_id": instance.charger_id,
+                "parent_id": instance.path[-1] if instance.path else instance.id,
+            }
         )
     except Department.DoesNotExist:
         return Resp(code=ServerErrorCode, msg=f"the department can't be found  id: {pk}")
@@ -183,7 +189,7 @@ def update_department(pk: int, data: dict):
     checked = DepartmentForms(data)
     # 判断数据合法性
     if not checked.is_valid():
-        return Resp(code=ServerErrorCode, msg="error", data=checked.errors)
+        return Resp(code=ServerErrorCode, msg=checked.errors)
     organization_id = data["organization_id"]
     try:
         instance = Department.objects.get(pk=pk, organization_id=organization_id, is_deleted=False)
@@ -305,7 +311,7 @@ def delete_department_user_map(organization_id: int, department_id: int, user_id
     if not Department.objects.filter(
             organization_id=organization_id, pk=department_id
     ).exists():
-        return Resp(code=BadRequestCode, msg="error", data="当前组织没有该部门")
+        return Resp(code=BadRequestCode, msg="当前组织没有该部门")
 
     DepartmentUserMap.objects.filter(
         department__organization_id=organization_id,
@@ -360,18 +366,6 @@ def mv_show_order(organization_id: int, data: dict):
     return Resp()
 
 
-
-
-    #
-    # for item in data:
-    #     obj = Department.objects.filter(id=item["id"], organization_id=organization_id)
-    #     if not obj:
-    #         raise ValueError(f"organization {organization_id} not found department {item['id']}")
-    #     obj.update(show_order=item["show_order"])
-
-    return Resp()
-
-
 def get_all_chargers(organization_id):
     return Resp(data=list(DepartmentUserMap.objects.filter(
         department__organization_id=organization_id,
